@@ -7,6 +7,7 @@ class Analyze():
         self.force = []
         self.displacement = []
         self.run = False
+        self.title = ""
 
     def decode(self):
         if self.run == True:
@@ -41,7 +42,7 @@ class Analyze():
         plt.plot(self.time, self.force)
         plt.ylabel("Force (N)")
         plt.xlabel("Time (s)")
-        plt.title("Force vs. Time")
+        plt.title(self.title + " Force vs. Time")
         plt.show()        
 
     def plotdisplacementvtime(self):
@@ -51,7 +52,7 @@ class Analyze():
         plt.plot(self.time, self.displacement)
         plt.ylabel("Displacement (mm)")
         plt.xlabel("Time (s)")
-        plt.title("Displacement vs. Time")
+        plt.title(self.title + " Displacement vs. Time")
         plt.show()        
 
     def plotforcevdisplacement(self):
@@ -62,7 +63,7 @@ class Analyze():
         plt.plot(self.displacement, self.force)
         plt.ylabel("Force (N)")
         plt.xlabel("Displacement (mm)")
-        plt.title("Force vs. Displacement")
+        plt.title(self.title + " Force vs. Displacement")
         plt.show()        
 
 
